# testpackagemds 


[![codecov](https://codecov.io/gh/flor14/testpackagemds/branch/main/graph/badge.svg)](https://codecov.io/gh/flor14/testpackagemds)



A package created to try a GitHub Actions workflow! :)


[![ci-cd](https://github.com/flor14/testpackagemds/actions/workflows/ci-cd.yml/badge.svg)](https://github.com/flor14/testpackagemds/actions/workflows/ci-cd.yml)

A package created to try a GitHub Actions workflow!


## Installation

```bash
$ pip install testpackagemds
```

## Usage



## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.




